import React, { createContext, memo, useContext } from 'react';

const HighlightContext = createContext(null);
const Provider = ({ children, ...props }) => {
    return (React.createElement(HighlightContext.Provider, { value: props }, children));
};

function findOccurrences(content, contentLower, keyword) {
    keyword = keyword.toLocaleLowerCase();
    const occ = [];
    for (let i = 0; (i = contentLower.indexOf(keyword, i)) > -1; i += keyword.length) {
        occ.push({
            start: i,
            end: i + keyword.length,
            raw: content.substr(i, keyword.length),
        });
    }
    return occ;
}
function replaceOccurrences(content, keywords, wrapHighlight) {
    const res = [];
    const contentLower = content.toLocaleLowerCase();
    const occurrences = keywords
        .map((keyword) => findOccurrences(content, contentLower, keyword.toLocaleLowerCase()))
        .flat()
        .sort((a, b) => a.start - b.start);
    let i = 0;
    let id = 0;
    for (const occ of occurrences) {
        if (occ.start !== 0)
            res.push(React.createElement("span", { key: id++ }, content.substring(i, occ.start)));
        res.push(wrapHighlight(occ.raw, id++));
        i = occ.end;
    }
    if (i != content.length)
        res.push(React.createElement("span", { key: id++ }, content.substr(i)));
    return res;
}
const Highlight = memo(({ content, keywords, highlightClassName }) => {
    var _a, _b;
    const ctx = useContext(HighlightContext);
    keywords = (keywords !== null && keywords !== void 0 ? keywords : []).concat((_a = ctx === null || ctx === void 0 ? void 0 : ctx.keywords) !== null && _a !== void 0 ? _a : []);
    highlightClassName = (_b = ctx === null || ctx === void 0 ? void 0 : ctx.highlightClassName) !== null && _b !== void 0 ? _b : highlightClassName;
    return (React.createElement(React.Fragment, null, replaceOccurrences(content, keywords !== null && keywords !== void 0 ? keywords : [], (c, id) => (React.createElement("span", { key: id, className: highlightClassName !== null && highlightClassName !== void 0 ? highlightClassName : 'highlight-highlighted' }, c)))));
});

function useHighlightContext() {
    return useContext(HighlightContext);
}

export { Highlight, HighlightContext, Provider, useHighlightContext };
