'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

const HighlightContext = React.createContext(null);
const Provider = ({ children, ...props }) => {
    return (React__default["default"].createElement(HighlightContext.Provider, { value: props }, children));
};

function findOccurrences(content, contentLower, keyword) {
    keyword = keyword.toLocaleLowerCase();
    const occ = [];
    for (let i = 0; (i = contentLower.indexOf(keyword, i)) > -1; i += keyword.length) {
        occ.push({
            start: i,
            end: i + keyword.length,
            raw: content.substr(i, keyword.length),
        });
    }
    return occ;
}
function replaceOccurrences(content, keywords, wrapHighlight) {
    const res = [];
    const contentLower = content.toLocaleLowerCase();
    const occurrences = keywords
        .map((keyword) => findOccurrences(content, contentLower, keyword.toLocaleLowerCase()))
        .flat()
        .sort((a, b) => a.start - b.start);
    let i = 0;
    let id = 0;
    for (const occ of occurrences) {
        if (occ.start !== 0)
            res.push(React__default["default"].createElement("span", { key: id++ }, content.substring(i, occ.start)));
        res.push(wrapHighlight(occ.raw, id++));
        i = occ.end;
    }
    if (i != content.length)
        res.push(React__default["default"].createElement("span", { key: id++ }, content.substr(i)));
    return res;
}
const Highlight = React.memo(({ content, keywords, highlightClassName }) => {
    var _a, _b;
    const ctx = React.useContext(HighlightContext);
    keywords = (keywords !== null && keywords !== void 0 ? keywords : []).concat((_a = ctx === null || ctx === void 0 ? void 0 : ctx.keywords) !== null && _a !== void 0 ? _a : []);
    highlightClassName = (_b = ctx === null || ctx === void 0 ? void 0 : ctx.highlightClassName) !== null && _b !== void 0 ? _b : highlightClassName;
    return (React__default["default"].createElement(React__default["default"].Fragment, null, replaceOccurrences(content, keywords !== null && keywords !== void 0 ? keywords : [], (c, id) => (React__default["default"].createElement("span", { key: id, className: highlightClassName !== null && highlightClassName !== void 0 ? highlightClassName : 'highlight-highlighted' }, c)))));
});

function useHighlightContext() {
    return React.useContext(HighlightContext);
}

exports.Highlight = Highlight;
exports.HighlightContext = HighlightContext;
exports.Provider = Provider;
exports.useHighlightContext = useHighlightContext;
